<?php

require_once 'config.php';

/* Basic request URL */
define('URL', 'csec.api.qcloud.com/v2/index.php');

function sendRequest($url, $method = 'POST')
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_TIMEOUT, 10);

    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    if (false !== strpos($url, "https")) {
        // 证书
        // curl_setopt($ch,CURLOPT_CAINFO,"ca.crt");
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    }
    $resultStr = curl_exec($ch);
    $result = json_decode($resultStr, true);

    return $result;
}

/* Generates an available URL */
function makeURL($method, $action, $region, $secretId, $secretKey, $args)
{
    /* Add common parameters */
    $args['Nonce'] = (string)rand(0, 0x7fffffff);
    $args['Action'] = $action;
    $args['Region'] = $region;
    $args['SecretId'] = $secretId;
    $args['Timestamp'] = (string)time();

    /* Sort by key (ASCII order, ascending), then calculate signature using HMAC-SHA1 algorithm */
    ksort($args);
    $args['Signature'] = base64_encode(
        hash_hmac(
            'sha1', $method . URL . '?' . makeQueryString($args, false),
            $secretKey, true
        )
    );

    /* Assemble final request URL */

    return 'https://' . URL . '?' . makeQueryString($args, true);
}

/* Construct query string from array */
function makeQueryString($args, $isURLEncoded)
{
    $arr = array();
    foreach ($args as $key => $value) {
        if (!$isURLEncoded) {
            $arr[] = "$key=$value";
        } else {
            $arr[] = $key . '=' . urlencode($value);
        }
    }
    return implode('&', $arr);
}

/* Demo section */
function getJsUrl()
{
    /*
    * 补充用户、行为信息数据,方便我们做更准确的数据模型
    * 协议参考 https://www.qcloud.com/doc/api/254/2897
    */
    $url = makeURL(
        'GET',
        'CaptchaIframeQuery',
        'sz',
        SECRET_ID,
        SECRET_KEY,

        array(
            /* 行为信息参数 */
            'userIp'       => '127.0.0.1',

            /* 验证码信息参数 */
            'captchaType'  => CAPTACHA_TYPE,
            'disturbLevel' => DISTURB_LEVEL,
            'isHttps'      => IS_HTTPS,
            'clientType'  => CLIENT_TYPE,

            /* 其他信息参数 */
            'businessId'   => BUSINESS_ID
        )
    );
    $result = sendRequest($url);
    $jsUrl = $result['url'];

    return $jsUrl;
}

function Check($ticket)
{
    /*
    * 补充用户、行为信息数据,方便我们做更准确的数据模型
    * 协议参考 https://www.qcloud.com/doc/api/254/2898
    */
    $url = makeURL(
        'GET',
        'CaptchaCheck',
        'sz',
        SECRET_ID,
        SECRET_KEY,

        array(
            /* 行为信息参数 */
            'userIp'      => '127.0.0.1',

            /* 验证码信息参数 */
            'captchaType' => CAPTACHA_TYPE,
            'ticket'      => $ticket,
            'verifyType'  => VERIFY_TYPE, // 验证类型，默认填0，如果js页面参数配置了firstvrytype=2，启动了滑动验证功能，则该值必填，而且必须跟firstvrytype的值保持一致
            /* 其他信息参数 */
            'businessId'  => BUSINESS_ID
        )
    );
    $result = sendRequest($url);

    return $result;
}
